@@ -1,4 +1,5 @@
 from contextlib import contextmanager
+from numbers import Number
 from time import sleep
 from bisect import bisect_left
 from itertools import combinations_with_replacement
@@ -32,15 +33,11 @@ def lcm(numbers: Collection = None, *args: int) -> int:
     return int(lcm)
 
 class PrimeNumbers(object):
-    """Iterable object which yields prime numbers
+    """Iterable object which yields prime numbers (infinitely!)
+
     Creates a cache of known primes which is accessed by all active instances
-    Each instance stores its last known position - so you can use it multiple times to get next prime, if this makes sense for you
     
-    Can be initiated at any time with PrimeNumbers.preseed(n) to calculate all primes < n using sieve
-    Do this if you are sure you actually need that many primes
-    
-    Use startat1 = True if you want the first result to be 1
-    Maybe useful if you want p[i] to give i-th prime and 1 is the zero-th prime, 2 is 1st prime etc.
+    Use n in PrimeNumbers() to test whether n is prime
     """
 
     _knownprimes = [1,2,3,5,7]
@@ -59,10 +56,20 @@ class PrimeNumbers(object):
         return cls()
 
     def __init__(self, startat1 = False) -> None:
+        """
+        startat1 = False (default) will yield 2,3,5,...
+        
+        startat1 = True will yield 1, 2, 3, 5, ...
+
+        PrimeNumbers.preseed(n) will pre-calculate all primes < n using sieve for faster access at cost of slower initiation.
+        Do this if you are sure you actually need that many primes
+        """
+
         cls = self.__class__
         if cls._prime == None:
             cls._prime = cls._generateprimes()
         self.i = -1
+        self._startat1 = startat1
         if not startat1:
             self.i += 1
         
@@ -79,6 +86,27 @@ class PrimeNumbers(object):
             next(cls._prime)
         return cls._knownprimes[self.i]
 
+    def __contains__(self, __o):
+        
+        if __o != int(__o.real):
+            return False
+        else:
+            __o = int(__o.real)
+        
+        cls = self.__class__
+        if __o <= max(cls._knownprimes):    
+            if self._startat1:
+                return __o in cls._knownprimes
+            else:
+                return __o in cls._knownprimes[1:]
+        else:
+            primes = PrimeNumbers()
+            for p in primes:
+                if __o%p == 0:
+                    return False
+                elif p*p > __o:
+                    return True
+
     @classmethod
     def _generateprimes(cls):
         #calculates potential primes using n = ak + j where:
